package com.jiuqi.dna.ide.designer.workflow;

import com.jiuqi.dna.ide.designer.DesignerElementFactory;
import com.jiuqi.dna.ide.designer.DesignerMessages;
import com.jiuqi.dna.ide.designer.elements.DesignerElement;
import com.jiuqi.dna.ide.designer.elements.FigureElement;
import com.jiuqi.dna.ide.designer.toolkit.ToolkitElement;
import com.jiuqi.dna.ide.designer.toolkit.ToolkitManager;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;
import org.eclipse.gef.palette.CombinedTemplateCreationEntry;
import org.eclipse.gef.palette.ConnectionCreationToolEntry;
import org.eclipse.gef.palette.MarqueeToolEntry;
import org.eclipse.gef.palette.PaletteContainer;
import org.eclipse.gef.palette.PaletteDrawer;
import org.eclipse.gef.palette.PaletteEntry;
import org.eclipse.gef.palette.PaletteGroup;
import org.eclipse.gef.palette.PaletteRoot;
import org.eclipse.gef.palette.PaletteSeparator;
import org.eclipse.gef.palette.PaletteStack;
import org.eclipse.gef.palette.PanningSelectionToolEntry;
import org.eclipse.gef.requests.CreationFactory;
import org.eclipse.gef.tools.MarqueeSelectionTool;
import org.eclipse.jface.resource.ImageDescriptor;

/* loaded from: com_jiuqi_dna_ide_designer_workflow.jar:com/jiuqi/dna/ide/designer/workflow/WorkflowDesignerPaletteFactory.class */
public final class WorkflowDesignerPaletteFactory {
    private WorkflowDesignerPaletteFactory() {
    }

    public static PaletteRoot createPalette(WorkflowDesignerBase designerBase) {
        PaletteRoot palette = new PaletteRoot();
        palette.add(createToolsGroup(palette));
        ArrayList<String> catalogs = ToolkitManager.getWorkflowElementCatalogs();
        Iterator<String> it = catalogs.iterator();
        while (it.hasNext()) {
            String catalog = it.next();
            palette.add(createToolkitElementCatalog(catalog, designerBase));
        }
        return palette;
    }

    private static PaletteContainer createToolsGroup(PaletteRoot root) {
        PaletteGroup toolGroup = new PaletteGroup(DesignerMessages.WorkflowDesigner_Palette_ToolsGroup_Name);
        List<PaletteEntry> entries = new ArrayList<>();
        PanningSelectionToolEntry panningSelectionToolEntry = new PanningSelectionToolEntry();
        entries.add(panningSelectionToolEntry);
        root.setDefaultEntry(panningSelectionToolEntry);
        PaletteStack marqueeStack = new PaletteStack(DesignerMessages.Designer_Palette_ToolsGroup_MarqueeStack, "", (ImageDescriptor) null);
        marqueeStack.add(new MarqueeToolEntry());
        MarqueeToolEntry marquee = new MarqueeToolEntry();
        marquee.setToolProperty(MarqueeSelectionTool.PROPERTY_MARQUEE_BEHAVIOR, new Integer(MarqueeSelectionTool.BEHAVIOR_CONNECTIONS_TOUCHED));
        marqueeStack.add(marquee);
        MarqueeToolEntry marquee2 = new MarqueeToolEntry();
        marquee2.setToolProperty(MarqueeSelectionTool.PROPERTY_MARQUEE_BEHAVIOR, new Integer(MarqueeSelectionTool.BEHAVIOR_CONNECTIONS_TOUCHED | MarqueeSelectionTool.BEHAVIOR_NODES_CONTAINED));
        marqueeStack.add(marquee2);
        marqueeStack.setUserModificationPermission(1);
        entries.add(marqueeStack);
        entries.add(new PaletteSeparator());
        entries.add(new ConnectionCreationToolEntry(DesignerMessages.WorkflowDesigner_Palette_ToolsGroup_Link_Name, DesignerMessages.WorkflowDesigner_Palette_ToolsGroup_Link_Description, (CreationFactory) null, ImageDescriptor.createFromFile(DesignerElement.class, "icons/connection_s16.gif"), ImageDescriptor.createFromFile(DesignerElement.class, "icons/connection_s24.gif")));
        toolGroup.addAll(entries);
        return toolGroup;
    }

    private static PaletteContainer createToolkitElementCatalog(String catalogName, WorkflowDesignerBase designerBase) {
        PaletteDrawer catalog = new PaletteDrawer(catalogName);
        List<PaletteEntry> entries = new ArrayList<>();
        ArrayList<String> groups = ToolkitManager.getWorkflowElementGroupsByCatalog(catalogName);
        for (int i = 0; i < groups.size(); i++) {
            ArrayList<ToolkitElement> group = ToolkitManager.getWorkflowElementsByCatalogAndGroup(catalogName, groups.get(i));
            Iterator<ToolkitElement> it = group.iterator();
            while (it.hasNext()) {
                ToolkitElement element = it.next();
                CombinedTemplateCreationEntry entry = new CombinedTemplateCreationEntry(element.getName(), element.getDescription(), new DesignerElementFactory(getElementClass(element), element, designerBase), element.getSmallIcon(), element.getLargeIcon());
                element.setToolEntry(entry);
                entries.add(entry);
            }
            if (i < groups.size() - 1) {
                entries.add(new PaletteSeparator());
            }
        }
        catalog.addAll(entries);
        return catalog;
    }

    private static Class<?> getElementClass(ToolkitElement element) {
        return FigureElement.class;
    }
}
